@@ -1,11 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2006 by Matthew Williams    <matt@milliams.com>         *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2006 Matthew Williams <matt@milliams.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef GAMEBOARDVIEW_H
 #define GAMEBOARDVIEW_H
@@ -36,7 +33,7 @@ public:
     /**
      * Asks the scene through ( qobject_cast<GameBoardScene*>(scene()) ) for the smallest size it should be
      */
-    QSize minimumSizeHint() const Q_DECL_OVERRIDE
+    QSize minimumSizeHint() const override
     {
         if (scene() == nullptr) {
             return QSize();
@@ -49,7 +46,7 @@ public Q_SLOTS:
     void setBoardSize();
 protected:
     ///Overloaded to resize board.
-    void resizeEvent(QResizeEvent *event) Q_DECL_OVERRIDE
+    void resizeEvent(QResizeEvent *event) override
     {
         if (scene() != nullptr) {
             fitInView(scene()->sceneRect(), Qt::KeepAspectRatio);
